@@ -1,39 +1,25 @@
 package com.lmax.disruptor;
 
-import static org.hamcrest.Matchers.greaterThanOrEqualTo;
-import static org.junit.Assert.*;
+import com.lmax.disruptor.support.DummySequenceBarrier;
+import org.junit.Test;
 
 import java.util.concurrent.TimeUnit;
 
-import org.jmock.Expectations;
-import org.jmock.Mockery;
-import org.jmock.integration.junit4.JMock;
-import org.junit.Test;
-import org.junit.runner.RunWith;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-@RunWith(JMock.class)
 public class TimeoutBlockingWaitStrategyTest
 {
-    private final Mockery mockery = new Mockery();
-
     @Test
     public void shouldTimeoutWaitFor() throws Exception
     {
-        final SequenceBarrier sequenceBarrier = mockery.mock(SequenceBarrier.class);
+        final SequenceBarrier sequenceBarrier = new DummySequenceBarrier();
 
         long theTimeout = 500;
         TimeoutBlockingWaitStrategy waitStrategy = new TimeoutBlockingWaitStrategy(theTimeout, TimeUnit.MILLISECONDS);
         Sequence cursor = new Sequence(5);
         Sequence dependent = cursor;
 
-        mockery.checking(
-            new Expectations()
-            {
-                {
-                    allowing(sequenceBarrier).checkAlert();
-                }
-            });
-
         long t0 = System.currentTimeMillis();
 
         try
@@ -49,6 +35,6 @@ public class TimeoutBlockingWaitStrategyTest
 
         long timeWaiting = t1 - t0;
 
-        assertThat(timeWaiting, greaterThanOrEqualTo(theTimeout));
+        assertTrue(timeWaiting >= theTimeout);
     }
 }
